@@ -43,8 +43,6 @@ public:
    * @param severity the severity level of the log event.
    * @param name the name of the log event.
    * @param message the string message of the log (perhaps support std::fmt or fmt-lib format).
-   * @param resource the resources, stored as a 2D list of key/value pairs, that are associated
-   * with the log event.
    * @param attributes the attributes, stored as a 2D list of key/value pairs, that are associated
    * with the log event.
    * @param trace_id the trace id associated with the log event.
@@ -57,13 +55,10 @@ public:
   /**
    * The base Log(...) method that all other Log(...) overloaded methods will eventually call,
    * in order to create a log record.
-   *
-   * Note this takes in a KeyValueIterable for the resource and attributes fields.
    */
   virtual void Log(Severity severity,
                    nostd::string_view name,
                    nostd::string_view body,
-                   const common::KeyValueIterable &resource,
                    const common::KeyValueIterable &attributes,
                    trace::TraceId trace_id,
                    trace::SpanId span_id,
@@ -74,31 +69,25 @@ public:
   /**
    * The secondary base Log(...) method that all other Log(...) overloaded methods except the one
    * above will eventually call,  in order to create a log record.
-   *
-   * Note this takes in template types for the resource and attributes fields.
    */
   template <class T,
-            class U,
-            nostd::enable_if_t<common::detail::is_key_value_iterable<T>::value> * = nullptr,
-            nostd::enable_if_t<common::detail::is_key_value_iterable<U>::value> * = nullptr>
+            nostd::enable_if_t<common::detail::is_key_value_iterable<T>::value> * = nullptr>
   void Log(Severity severity,
            nostd::string_view name,
            nostd::string_view body,
-           const T &resource,
-           const U &attributes,
+           const T &attributes,
            trace::TraceId trace_id,
            trace::SpanId span_id,
            trace::TraceFlags trace_flags,
            common::SystemTimestamp timestamp) noexcept
   {
-    Log(severity, name, body, common::KeyValueIterableView<T>(resource),
-        common::KeyValueIterableView<U>(attributes), trace_id, span_id, trace_flags, timestamp);
+    Log(severity, name, body, common::KeyValueIterableView<T>(attributes), trace_id, span_id,
+        trace_flags, timestamp);
   }
 
   void Log(Severity severity,
            nostd::string_view name,
            nostd::string_view body,
-           std::initializer_list<std::pair<nostd::string_view, common::AttributeValue>> resource,
            std::initializer_list<std::pair<nostd::string_view, common::AttributeValue>> attributes,
            trace::TraceId trace_id,
            trace::SpanId span_id,
@@ -106,8 +95,6 @@ public:
            common::SystemTimestamp timestamp) noexcept
   {
     return this->Log(severity, name, body,
-                     nostd::span<const std::pair<nostd::string_view, common::AttributeValue>>{
-                         resource.begin(), resource.end()},
                      nostd::span<const std::pair<nostd::string_view, common::AttributeValue>>{
                          attributes.begin(), attributes.end()},
                      trace_id, span_id, trace_flags, timestamp);
@@ -122,7 +109,7 @@ public:
    */
   void Log(Severity severity, nostd::string_view message) noexcept
   {
-    this->Log(severity, "", message, {}, {}, {}, {}, {}, std::chrono::system_clock::now());
+    this->Log(severity, "", message, {}, {}, {}, {}, std::chrono::system_clock::now());
   }
 
   /**
@@ -133,7 +120,7 @@ public:
    */
   void Log(Severity severity, nostd::string_view name, nostd::string_view message) noexcept
   {
-    this->Log(severity, name, message, {}, {}, {}, {}, {}, std::chrono::system_clock::now());
+    this->Log(severity, name, message, {}, {}, {}, {}, std::chrono::system_clock::now());
   }
 
   /**
@@ -145,8 +132,7 @@ public:
             nostd::enable_if_t<common::detail::is_key_value_iterable<T>::value> * = nullptr>
   void Log(Severity severity, const T &attributes) noexcept
   {
-    this->Log(severity, "", "", std::map<std::string, std::string>{}, attributes, {}, {}, {},
-              std::chrono::system_clock::now());
+    this->Log(severity, "", "", attributes, {}, {}, {}, std::chrono::system_clock::now());
   }
 
   /**
@@ -159,8 +145,7 @@ public:
             nostd::enable_if_t<common::detail::is_key_value_iterable<T>::value> * = nullptr>
   void Log(Severity severity, nostd::string_view name, const T &attributes) noexcept
   {
-    this->Log(severity, name, "", std::map<std::string, std::string>{}, attributes, {}, {}, {},
-              std::chrono::system_clock::now());
+    this->Log(severity, name, "", attributes, {}, {}, {}, std::chrono::system_clock::now());
   }
 
   /**
@@ -172,7 +157,7 @@ public:
            std::initializer_list<std::pair<nostd::string_view, common::AttributeValue>>
                attributes) noexcept
   {
-    this->Log(severity, "", "", {}, attributes, {}, {}, {}, std::chrono::system_clock::now());
+    this->Log(severity, "", "", attributes, {}, {}, {}, std::chrono::system_clock::now());
   }
 
   /**
@@ -186,7 +171,7 @@ public:
            std::initializer_list<std::pair<nostd::string_view, common::AttributeValue>>
                attributes) noexcept
   {
-    this->Log(severity, name, "", {}, attributes, {}, {}, {}, std::chrono::system_clock::now());
+    this->Log(severity, name, "", attributes, {}, {}, {}, std::chrono::system_clock::now());
   }
 
   /**
@@ -200,10 +185,7 @@ public:
            nostd::string_view name,
            common::KeyValueIterable &attributes) noexcept
   {
-    this->Log(severity, name, {},
-              common::KeyValueIterableView<
-                  std::initializer_list<std::pair<nostd::string_view, common::AttributeValue>>>({}),
-              attributes, {}, {}, {}, std::chrono::system_clock::now());
+    this->Log(severity, name, {}, attributes, {}, {}, {}, std::chrono::system_clock::now());
   }
 
   /** Trace severity overloads **/
